@@ -27,6 +27,7 @@ Q_LOGGING_CATEGORY(XdgDesktopPortalKdeDesktopPortal, "xdp-kde-desktop-portal")
 DesktopPortal::DesktopPortal(QObject *parent)
     : QObject(parent)
     , m_access(new AccessPortal(this))
+    , m_account(new AccountPortal(this))
     , m_appChooser(new AppChooserPortal(this))
     , m_email(new EmailPortal(this))
     , m_fileChooser(new FileChooserPortal(this))
@@ -37,12 +38,13 @@ DesktopPortal::DesktopPortal(QObject *parent)
 {
     const QByteArray xdgCurrentDesktop = qgetenv("XDG_CURRENT_DESKTOP").toUpper();
     if (xdgCurrentDesktop == "KDE") {
-        m_screenshot = new ScreenshotPortal(this);
-#if SCREENCAST_ENABLED
+        m_background = new BackgroundPortal(this);
+#if HAVE_PIPEWIRE_SUPPORT
         m_screenCast = new ScreenCastPortal(this);
         m_remoteDesktop = new RemoteDesktopPortal(this);
-        WaylandIntegration::init();
 #endif
+        m_screenshot = new ScreenshotPortal(this);
+        WaylandIntegration::init();
     }
 }
 
